==> kubernetes-model-admissionregistration-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/ExpressionWarningFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ExpressionWarningFluent<A extends ExpressionWarningFluent<A>> extends BaseFluent<A>{
  public ExpressionWarningFluent() {
  }
  
  public ExpressionWarningFluent(ExpressionWarning instance) {
    this.copyInstance(instance);
  }
  private String fieldRef;
  private String warning;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ExpressionWarning instance) {
    instance = (instance != null ? instance : new ExpressionWarning());
  
    if (instance != null) {
        this.withFieldRef(instance.getFieldRef());
        this.withWarning(instance.getWarning());
        this.withFieldRef(instance.getFieldRef());
        this.withWarning(instance.getWarning());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getFieldRef() {
    return this.fieldRef;
  }
  
  public A withFieldRef(String fieldRef) {
    this.fieldRef=fieldRef; return (A) this;
  }
  
  public boolean hasFieldRef() {
    return this.fieldRef != null;
  }
  
  public String getWarning() {
    return this.warning;
  }
  
  public A withWarning(String warning) {
    this.warning=warning; return (A) this;
  }
  
  public boolean hasWarning() {
    return this.warning != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ExpressionWarningFluent that = (ExpressionWarningFluent) o;
    if (!java.util.Objects.equals(fieldRef, that.fieldRef)) return false;
  
    if (!java.util.Objects.equals(warning, that.warning)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(fieldRef,  warning,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fieldRef != null) { sb.append("fieldRef:"); sb.append(fieldRef + ","); }
    if (warning != null) { sb.append("warning:"); sb.append(warning + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> kubernetes-model-admissionregistration-6.9.1-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/ExpressionWarningFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ExpressionWarningFluent<A extends ExpressionWarningFluent<A>> extends BaseFluent<A>{
  public ExpressionWarningFluent() {
  }
  
  public ExpressionWarningFluent(ExpressionWarning instance) {
    this.copyInstance(instance);
  }
  private String fieldRef;
  private String warning;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ExpressionWarning instance) {
    instance = (instance != null ? instance : new ExpressionWarning());
    if (instance != null) {
          this.withFieldRef(instance.getFieldRef());
          this.withWarning(instance.getWarning());
          this.withFieldRef(instance.getFieldRef());
          this.withWarning(instance.getWarning());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getFieldRef() {
    return this.fieldRef;
  }
  
  public A withFieldRef(String fieldRef) {
    this.fieldRef = fieldRef;
    return (A) this;
  }
  
  public boolean hasFieldRef() {
    return this.fieldRef != null;
  }
  
  public String getWarning() {
    return this.warning;
  }
  
  public A withWarning(String warning) {
    this.warning = warning;
    return (A) this;
  }
  
  public boolean hasWarning() {
    return this.warning != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ExpressionWarningFluent that = (ExpressionWarningFluent) o;
    if (!java.util.Objects.equals(fieldRef, that.fieldRef)) return false;
    if (!java.util.Objects.equals(warning, that.warning)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(fieldRef,  warning,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fieldRef != null) { sb.append("fieldRef:"); sb.append(fieldRef + ","); }
    if (warning != null) { sb.append("warning:"); sb.append(warning + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
